Some packages have logos already in curated repositories. This avoids additional CRAN calls and returns high definition versions of the logos.
check_known_repos(pkg_name, known_repos = getOption("hexFinder.known_repos"))A URL that points to a image or NULL in no result was found.
A single string with the name of a package to find the hex for.
Named list with known curated repos that store logos for some packages. quality on these is usually higher that normal.