Learn R Programming

hexFinder (version 0.8.2)

download_logo: Download a logo image

Description

Downloads a given URL and stores it using the package name into the specified output folder

Usage

download_logo(pkg_name, raw_url, output, crop = TRUE)

Value

The path where the downloaded image was stored.

Arguments

pkg_name

The name of the file to save.

raw_url

The image URL.

output

The Folder path where to store the download file.

crop

Should empty space be removed from the final image file.