Learn R Programming

hexFinder (version 0.8.2)

get_metacran_info: Returns metacran information about a given package

Description

Returns metacran information about a given package

Usage

get_metacran_info(pkg_name)

Value

A named list with metadata information about the package

Arguments

pkg_name

A single string with the name of a package to find the meta information for.