keep_good_ratio_images: Filters a list of image entries keeping images that might be a logo
Description
Filters a list of image entries keeping images that might be a logo
Usage
keep_good_ratio_images(paths, download_endpoint, branch)
Value
A list of path information
Arguments
- paths
A list of path information
- download_endpoint
The download endpoint for the repo
- branch
The repo active branch