Learn R Programming

hexFinder (version 0.8.2)

locate_repo: Finds the best repo for a given package

Description

All CRAN packages have a cloned github repo that we can query for logos, but CRAN only stores the actual content of the package file. By looking at meta CRAN links we can try to find the original repo and use that one instead.

Usage

locate_repo(pkg_name)

Value

A URL that points to a github repository.

Arguments

pkg_name

A single string with the name of a package to find the repo for.